@@ -8,10 +8,10 @@ from plaid.version import __version__
 
 
 ALLOWED_METHODS = {'post'}
-TIMEOUT = 600  # 10 minutes
+DEFAULT_TIMEOUT = 600  # 10 minutes
 
 
-def _requests_http_request(url, method, data):
+def _requests_http_request(url, method, data, timeout=DEFAULT_TIMEOUT):
     normalized_method = method.lower()
     if normalized_method in ALLOWED_METHODS:
         return getattr(requests, normalized_method)(
@@ -20,7 +20,7 @@ def _requests_http_request(url, method, data):
             headers={
                 'User-Agent': 'Plaid Python v{}'.format(__version__),
             },
-            timeout=TIMEOUT,
+            timeout=timeout,
         )
     else:
         raise Exception(
@@ -28,8 +28,8 @@ def _requests_http_request(url, method, data):
         )
 
 
-def http_request(url, method=None, data=None):
-    response = _requests_http_request(url, method, data or {})
+def http_request(url, method=None, data=None, timeout=DEFAULT_TIMEOUT):
+    response = _requests_http_request(url, method, data or {}, timeout)
     response_body = json.loads(response.text)
     if response_body.get('error_type'):
         raise PlaidError.from_response(response_body)
